@@ -38,6 +38,17 @@ class CfnAssessmentTarget(
 
     :cloudformationResource: AWS::Inspector::AssessmentTarget
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_inspector as inspector
+        
+        cfn_assessment_target = inspector.CfnAssessmentTarget(self, "MyCfnAssessmentTarget",
+            assessment_target_name="assessmentTargetName",
+            resource_group_arn="resourceGroupArn"
+        )
     '''
 
     def __init__(
@@ -80,25 +91,6 @@ class CfnAssessmentTarget(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> builtins.str:
-        '''
-        :cloudformationAttribute: Arn
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "attrArn"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="assessmentTargetName")
     def assessment_target_name(self) -> typing.Optional[builtins.str]:
@@ -112,6 +104,25 @@ class CfnAssessmentTarget(
     def assessment_target_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "assessmentTargetName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrArn")
+    def attr_arn(self) -> builtins.str:
+        '''
+        :cloudformationAttribute: Arn
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrArn"))
+
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="resourceGroupArn")
     def resource_group_arn(self) -> typing.Optional[builtins.str]:
@@ -147,6 +158,17 @@ class CfnAssessmentTargetProps:
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_inspector as inspector
+            
+            cfn_assessment_target_props = inspector.CfnAssessmentTargetProps(
+                assessment_target_name="assessmentTargetName",
+                resource_group_arn="resourceGroupArn"
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if assessment_target_name is not None:
@@ -194,6 +216,25 @@ class CfnAssessmentTemplate(
 
     :cloudformationResource: AWS::Inspector::AssessmentTemplate
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_inspector as inspector
+        
+        cfn_assessment_template = inspector.CfnAssessmentTemplate(self, "MyCfnAssessmentTemplate",
+            assessment_target_arn="assessmentTargetArn",
+            duration_in_seconds=123,
+            rules_package_arns=["rulesPackageArns"],
+        
+            # the properties below are optional
+            assessment_template_name="assessmentTemplateName",
+            user_attributes_for_findings=[CfnTag(
+                key="key",
+                value="value"
+            )]
+        )
     '''
 
     def __init__(
@@ -202,9 +243,9 @@ class CfnAssessmentTemplate(
         id: builtins.str,
         *,
         assessment_target_arn: builtins.str,
+        assessment_template_name: typing.Optional[builtins.str] = None,
         duration_in_seconds: jsii.Number,
         rules_package_arns: typing.Sequence[builtins.str],
-        assessment_template_name: typing.Optional[builtins.str] = None,
         user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Inspector::AssessmentTemplate``.
@@ -212,16 +253,16 @@ class CfnAssessmentTemplate(
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
+        :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param duration_in_seconds: ``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
         :param rules_package_arns: ``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
-        :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
         '''
         props = CfnAssessmentTemplateProps(
             assessment_target_arn=assessment_target_arn,
+            assessment_template_name=assessment_template_name,
             duration_in_seconds=duration_in_seconds,
             rules_package_arns=rules_package_arns,
-            assessment_template_name=assessment_template_name,
             user_attributes_for_findings=user_attributes_for_findings,
         )
 
@@ -245,25 +286,6 @@ class CfnAssessmentTemplate(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> builtins.str:
-        '''
-        :cloudformationAttribute: Arn
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "attrArn"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="assessmentTargetArn")
     def assessment_target_arn(self) -> builtins.str:
@@ -277,6 +299,38 @@ class CfnAssessmentTemplate(
     def assessment_target_arn(self, value: builtins.str) -> None:
         jsii.set(self, "assessmentTargetArn", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="assessmentTemplateName")
+    def assessment_template_name(self) -> typing.Optional[builtins.str]:
+        '''``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "assessmentTemplateName"))
+
+    @assessment_template_name.setter
+    def assessment_template_name(self, value: typing.Optional[builtins.str]) -> None:
+        jsii.set(self, "assessmentTemplateName", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrArn")
+    def attr_arn(self) -> builtins.str:
+        '''
+        :cloudformationAttribute: Arn
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrArn"))
+
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="durationInSeconds")
     def duration_in_seconds(self) -> jsii.Number:
@@ -303,19 +357,6 @@ class CfnAssessmentTemplate(
     def rules_package_arns(self, value: typing.List[builtins.str]) -> None:
         jsii.set(self, "rulesPackageArns", value)
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="assessmentTemplateName")
-    def assessment_template_name(self) -> typing.Optional[builtins.str]:
-        '''``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
-        '''
-        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "assessmentTemplateName"))
-
-    @assessment_template_name.setter
-    def assessment_template_name(self, value: typing.Optional[builtins.str]) -> None:
-        jsii.set(self, "assessmentTemplateName", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="userAttributesForFindings")
     def user_attributes_for_findings(
@@ -340,9 +381,9 @@ class CfnAssessmentTemplate(
     jsii_struct_bases=[],
     name_mapping={
         "assessment_target_arn": "assessmentTargetArn",
+        "assessment_template_name": "assessmentTemplateName",
         "duration_in_seconds": "durationInSeconds",
         "rules_package_arns": "rulesPackageArns",
-        "assessment_template_name": "assessmentTemplateName",
         "user_attributes_for_findings": "userAttributesForFindings",
     },
 )
@@ -351,20 +392,39 @@ class CfnAssessmentTemplateProps:
         self,
         *,
         assessment_target_arn: builtins.str,
+        assessment_template_name: typing.Optional[builtins.str] = None,
         duration_in_seconds: jsii.Number,
         rules_package_arns: typing.Sequence[builtins.str],
-        assessment_template_name: typing.Optional[builtins.str] = None,
         user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
+        :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param duration_in_seconds: ``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
         :param rules_package_arns: ``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
-        :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_inspector as inspector
+            
+            cfn_assessment_template_props = inspector.CfnAssessmentTemplateProps(
+                assessment_target_arn="assessmentTargetArn",
+                duration_in_seconds=123,
+                rules_package_arns=["rulesPackageArns"],
+            
+                # the properties below are optional
+                assessment_template_name="assessmentTemplateName",
+                user_attributes_for_findings=[CfnTag(
+                    key="key",
+                    value="value"
+                )]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "assessment_target_arn": assessment_target_arn,
@@ -386,6 +446,15 @@ class CfnAssessmentTemplateProps:
         assert result is not None, "Required property 'assessment_target_arn' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def assessment_template_name(self) -> typing.Optional[builtins.str]:
+        '''``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
+        '''
+        result = self._values.get("assessment_template_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def duration_in_seconds(self) -> jsii.Number:
         '''``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
@@ -406,15 +475,6 @@ class CfnAssessmentTemplateProps:
         assert result is not None, "Required property 'rules_package_arns' is missing"
         return typing.cast(typing.List[builtins.str], result)
 
-    @builtins.property
-    def assessment_template_name(self) -> typing.Optional[builtins.str]:
-        '''``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
-        '''
-        result = self._values.get("assessment_template_name")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def user_attributes_for_findings(
         self,
@@ -448,6 +508,19 @@ class CfnResourceGroup(
 
     :cloudformationResource: AWS::Inspector::ResourceGroup
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_inspector as inspector
+        
+        cfn_resource_group = inspector.CfnResourceGroup(self, "MyCfnResourceGroup",
+            resource_group_tags=[CfnTag(
+                key="key",
+                value="value"
+            )]
+        )
     '''
 
     def __init__(
@@ -485,12 +558,6 @@ class CfnResourceGroup(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
@@ -499,6 +566,12 @@ class CfnResourceGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
@@ -539,6 +612,19 @@ class CfnResourceGroupProps:
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_inspector as inspector
+            
+            cfn_resource_group_props = inspector.CfnResourceGroupProps(
+                resource_group_tags=[CfnTag(
+                    key="key",
+                    value="value"
+                )]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "resource_group_tags": resource_group_tags,
